@@ -727,8 +727,53 @@ class LaharFlowData(object):
             return d
         else:
             raise ValueError('File {} not recognized'.format(LaharFlowFile))
+
+    def latlon_in_data_extent(self, data, latlon):
+        fields = data.dtype.names
+        if 'latitude' not in fields:
+            raise ValueError('latitude not in data array')
+        if 'longitude' not in fields:
+            raise ValueError('longitude not in data array')
+
+        min_lat = data['latitude'].min()
+        max_lat = data['latitude'].max()
+        min_lon = data['longitude'].min()
+        max_lon = data['longitude'].max()
+
+        if latlon[0]<min_lat:
+            return False
+        if latlon[0]>max_lat:
+            return False
+        if latlon[1]<min_lon:
+            return False
+        if latlon[1]>max_lon:
+            return False
         
+        return True
     
+    def xy_in_data_extent(self, data, xy):
+        fields = data.dtype.names
+        if 'x_distance' not in fields:
+            raise ValueError('x_distance not in data array')
+        if 'y_distance' not in fields:
+            raise ValueError('y_distance not in data array')
+
+        min_x = data['x_distance'].min()
+        max_x = data['x_distance'].max()
+        min_y = data['y_distance'].min()
+        max_y = data['y_distance'].max()
+
+        if xy[0]<min_x:
+            return False
+        if xy[0]>max_x:
+            return False
+        if xy[1]<min_y:
+            return False
+        if xy[1]>max_y:
+            return False
+        
+        return True
+        
     def raster(self, filename, var=None, full_domain=False, nodata=np.nan, masked=True, crs=None, res=None):
         
         filetype = self._file_type(filename)
@@ -1352,8 +1397,7 @@ class LaharFlowData(object):
         return val
     
     def POI_buffer(self,  lon, lat, buffer, data=None, filename=None, var=None,
-                   full_domain=False, nodata=np.nan, 
-                   name='POI'):
+                   nodata=np.nan):
         
         if data is None and filename is None:
             raise RuntimeError('cannot have both data=None and filename=None')
@@ -1365,28 +1409,17 @@ class LaharFlowData(object):
 
         if filename is not None:
             data = self._get_data(filename)
-        POI_xy = np.array((self.clatlong, (lat, lon)))*1e3
+        POI_xy = np.array(EastingNorthing_TM(self.clatlong, (lat, lon)))*1e3
 
-        indx = np.sqrt((data['x_distance']-POI_xy[0])**2+(data['y_distance']-POI_xy[1])**2)<buffer
+        if self.xy_in_data_extent(data, POI_xy):
+
+            indx = np.sqrt((data['x_distance']-POI_xy[0])**2+(data['y_distance']-POI_xy[1])**2)<buffer
+
+            data_clipped = data[var][indx]
         
-        # n = np.count_nonzero(indx)
-
-        # dt = [
-        #     ('x_distance', np.float64),
-        #     ('y_distance', np.float64),
-        #     ('latitude', np.float64),
-        #     ('longitude', np.float64),
-        #     (var, np.float64)]
-
-        # data_clipped = np.full((n), np.nan, dtype=dt)
-
-        data_clipped = data[var][indx]
-        # data_clipped['x_distance'] = data['x_distance'][indx]
-        # data_clipped['y_distance'] = data['y_distance'][indx]
-        # data_clipped['latitude'] = data['latitude'][indx]
-        # data_clipped['longitude'] = data['longitude'][indx]
-        
-        return data_clipped
+            return data_clipped
+        else:
+            return nodata
     
     def transect_value(self, x, y, filename=None, data=None, var=None, full_domain=False, nodata=np.nan, fill_value=0, interp_method='linear'):
         
